@@ -59,10 +59,7 @@ class XMLTVFile(gobject.GObject):
         self.config = config
         self.listings = Listings(config)
 
-        arguments = self.config.grabber_command.split()
-        if "--output" in arguments:
-            index = arguments.index("--output") + 1
-            self.path = arguments[index]
+        self.path = self.config.xmltv_file
 
         self.__channel_names = {}
 
